@@ -1,14 +1,15 @@
+"""Bikemi Unofficial API."""
 import sys
 
 if sys.version_info[:2] >= (3, 8):
-    # TODO: Import directly (no need for conditional) when `python_requires = >= 3.8`
+    # TODO: Import directly (no need for conditional) when `python_requires = >= 3.8` # pylint: disable=fixme
     from importlib.metadata import PackageNotFoundError, version  # pragma: no cover
 else:
     from importlib_metadata import PackageNotFoundError, version  # pragma: no cover
 
 try:
     # Change here if project is renamed and does not equal the package name
-    dist_name = "BikeMi-unofficial-API"
+    dist_name = "BikeMi-unofficial-API"  # pylint: disable=invalid-name
     __version__ = version(dist_name)
 except PackageNotFoundError:  # pragma: no cover
     __version__ = "unknown"
